@@ -1080,7 +1080,7 @@ void GdbTest::testVariablesQuicklySwitchFrame()
     COMPARE_DATA(i, "Locals");
     QCOMPARE(variableCollection()->rowCount(i), 1);
     COMPARE_DATA(variableCollection()->index(0, 0, i), "i");
-    COMPARE_DATA(variableCollection()->index(1, 0, i), "1");
+    COMPARE_DATA(variableCollection()->index(0, 1, i), "1");
 
     stackModel->setCurrentFrame(1);
     QTest::qWait(300);
@@ -1108,6 +1108,71 @@ void GdbTest::testVariablesQuicklySwitchFrame()
     WAIT_FOR_STATE(session, DebugSession::EndedState);
 }
 
+
+void GdbTest::testSegfaultDebugee()
+{
+    TestDebugSession *session = new TestDebugSession;
+    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateLocals);
+    TestLaunchConfiguration cfg(KUrl(QDir::currentPath()+"/unittests/debugeecrash"));
+    QString fileName = QFileInfo(__FILE__).dir().path()+"/debugeecrash.cpp";
+
+    breakpoints()->addCodeBreakpoint(fileName, 23);
+
+    QVERIFY(session->startProgram(&cfg));
+
+    WAIT_FOR_STATE(session, DebugSession::PausedState);
+    QCOMPARE(session->line(), 23);
+    session->run();
+
+    WAIT_FOR_STATE(session, DebugSession::StoppedState);
+    QCOMPARE(session->line(), 24);
+
+    session->stopDebugger();
+    WAIT_FOR_STATE(session, DebugSession::EndedState);
+}
+
+void GdbTest::testSwitchFrameGdbConsole()
+{
+    TestDebugSession *session = new TestDebugSession;
+
+    TestLaunchConfiguration cfg;
+
+    TestFrameStackModel *stackModel = session->frameStackModel();
+
+    breakpoints()->addCodeBreakpoint(debugeeFileName, 24);
+    QVERIFY(session->startProgram(&cfg));
+    WAIT_FOR_STATE(session, DebugSession::PausedState);
+    QCOMPARE(stackModel->currentFrame(), 0);
+    stackModel->setCurrentFrame(1);
+    QCOMPARE(stackModel->currentFrame(), 1);
+    QTest::qWait(500);
+    QCOMPARE(stackModel->currentFrame(), 1);
+
+    session->slotUserGDBCmd("print x");
+    QTest::qWait(500);
+    //currentFrame must not reset to 0; Bug 222882
+    QCOMPARE(stackModel->currentFrame(), 1);
+
+}
+
+//Bug 201771
+void GdbTest::testInsertAndRemoveBreakpointWhileRunning()
+{
+    TestDebugSession *session = new TestDebugSession;
+    TestLaunchConfiguration cfg(KUrl(QDir::currentPath()+"/unittests/debugeeslow"));
+    QString fileName = QFileInfo(__FILE__).dir().path()+"/debugeeslow.cpp";
+
+    session->startProgram(&cfg);
+
+    WAIT_FOR_STATE(session, DebugSession::ActiveState);
+    QTest::qWait(2000);
+    kDebug() << "adding breakpoint";
+    KDevelop::Breakpoint *b = breakpoints()->addCodeBreakpoint(fileName, 23);
+    b->setDeleted();
+    WAIT_FOR_STATE(session, DebugSession::EndedState);
+}
+
+
 void GdbTest::waitForState(GDBDebugger::DebugSession *session, DebugSession::DebuggerState state,
                             const char *file, int line)
 {
