@@ -1,4 +1,4 @@
-/* This file is part of KDevelop
+  /* This file is part of KDevelop
     Copyright 2006 Roberto Raggi <roberto@kdevelop.org>
     Copyright 2006-2008 Hamish Rodda <rodda@kde.org>
     Copyright 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
@@ -105,6 +105,8 @@ ContextBuilder::ContextBuilder ()
   , m_templateDeclarationDepth(0)
   , m_typeSpecifierWithoutInitDeclarators((uint)-1)
   , m_onlyComputeVisible(false)
+  , m_onlyComputeSimplified(false)
+  , m_computeEmpty(false)
   , m_currentInitializer(0)
   , m_mapAst(false)
 {
@@ -116,6 +118,8 @@ ContextBuilder::ContextBuilder (ParseSession* session)
   , m_templateDeclarationDepth(0)
   , m_typeSpecifierWithoutInitDeclarators((uint)-1)
   , m_onlyComputeVisible(false)
+  , m_onlyComputeSimplified(false)
+  , m_computeEmpty(false)
   , m_currentInitializer(0)
   , m_mapAst(false)
 {
@@ -128,6 +132,8 @@ ContextBuilder::ContextBuilder (CppEditorIntegrator* editor)
   , m_templateDeclarationDepth(0)
   , m_typeSpecifierWithoutInitDeclarators((uint)-1)
   , m_onlyComputeVisible(false)
+  , m_onlyComputeSimplified(false)
+  , m_computeEmpty(false)
   , m_currentInitializer(0)
   , m_mapAst(false)
 {
@@ -138,6 +144,17 @@ void ContextBuilder::setOnlyComputeVisible(bool onlyVisible) {
   m_onlyComputeVisible = onlyVisible;
 }
 
+void ContextBuilder::setComputeSimplified(bool simplified)
+{
+  m_onlyComputeSimplified = simplified;
+}
+
+void ContextBuilder::setComputeEmpty(bool empty)
+{
+  m_computeEmpty = empty;
+}
+
+
 void ContextBuilder::createUserProblem(AST* node, QString text) {
     DUChainWriteLocker lock(DUChain::lock());
     KDevelop::ProblemPointer problem(new KDevelop::Problem);
@@ -299,21 +316,24 @@ void ContextBuilder::closePrefixContext(const QualifiedIdentifier& id) {
 
 void ContextBuilder::visitTemplateDeclaration(TemplateDeclarationAST * ast) {
 
-  AST* first, *last;
-  getFirstLast(&first, &last, ast->template_parameters);
-  DUContext* ctx = 0;
-
   ++m_templateDeclarationDepth;
-
-  if( first && last )
-    ctx = openContext(first, last, DUContext::Template); //Open anonymous context for the template-parameters
-  else
-    ctx = openContextEmpty(ast, DUContext::Template); //Open an empty context, because there are no template-parameters
-
-  visitNodes(this,ast->template_parameters);
-  closeContext();
   
-  queueImportedContext(ctx); //Import the context into the following function-argument context(so the template-parameters can be found from there)
+  if(!m_onlyComputeSimplified)
+  {
+    AST* first, *last;
+    getFirstLast(&first, &last, ast->template_parameters);
+    DUContext* ctx = 0;
+
+    if( first && last )
+      ctx = openContext(first, last, DUContext::Template); //Open anonymous context for the template-parameters
+    else
+      ctx = openContextEmpty(ast, DUContext::Template); //Open an empty context, because there are no template-parameters
+
+    visitNodes(this,ast->template_parameters);
+    closeContext();
+    
+    queueImportedContext(ctx); //Import the context into the following function-argument context(so the template-parameters can be found from there)
+  }
 
   DefaultVisitor::visit(ast->declaration);
 
@@ -433,8 +453,6 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
 
     setEncountered(topLevelContext);
 
-    node->ducontext = topLevelContext;
-
     if (includes) {
       if(removeOldImports) {
         foreach (const DUContext::Import &parent, topLevelContext->importedParentContexts())
@@ -455,7 +473,6 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
       
       topLevelContext->updateImportsCache();
     }
-    
   }
 
   {
@@ -464,7 +481,15 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
     ifDebugFile( HashedString(file->identity().url().str()), { kDebug() << stringFromContents(editor()->parseSession()->contentsVector()); Cpp::DumpChain dump; dump.dump(node, editor()->parseSession()); } );
   }
 
-  supportBuild(node);
+  if(m_computeEmpty)
+  {
+    //Empty the top-context, in case we're updating
+    DUChainWriteLocker lock(DUChain::lock());
+    topLevelContext->cleanIfNotEncountered(QSet<DUChainBase*>());
+  }else{
+    node->ducontext = topLevelContext;
+    supportBuild(node);
+  }
 
   {
     LockedSmartInterface iface = editor()->smart();
@@ -565,6 +590,9 @@ void ContextBuilder::visitNamespace (NamespaceAST *node)
 
 void ContextBuilder::visitEnumSpecifier(EnumSpecifierAST* node)
 {
+  if(m_onlyComputeSimplified)
+    return;
+  
   //The created context must be unnamed, so the enumerators can be found globally with the correct scope
   openContext(node, DUContext::Enum, 0 );
 
@@ -860,6 +888,11 @@ public:
 
 void ContextBuilder::visitExpressionOrDeclarationStatement(ExpressionOrDeclarationStatementAST* node)
 {
+  if(m_onlyComputeSimplified) {
+    visit(node->declaration);
+    return;
+  }
+  
   DUContext::ContextType type;
   {
     DUChainReadLocker lock(DUChain::lock());
@@ -949,6 +982,17 @@ void ContextBuilder::createTypeForDeclarator(DeclaratorAST* /*node*/) {
 void ContextBuilder::closeTypeForDeclarator(DeclaratorAST* /*node*/) {
 }
 
+void ContextBuilder::visitParameterDeclarationClause(ParameterDeclarationClauseAST* node)
+{
+  //Don't assign the initializer to parameter-declarations
+  InitializerAST* oldCurrentInitializer = m_currentInitializer;
+  m_currentInitializer = 0;
+  
+  DefaultVisitor::visitParameterDeclarationClause(node);
+  
+  m_currentInitializer = oldCurrentInitializer;
+}
+
 void ContextBuilder::visitInitDeclarator(InitDeclaratorAST *node)
 {
   QualifiedIdentifier id;
@@ -971,6 +1015,7 @@ void ContextBuilder::visitInitDeclarator(InitDeclaratorAST *node)
 }
 
 void ContextBuilder::visitDeclarator(DeclaratorAST *node) {
+  
   //BEGIN Copied from default visitor
   visit(node->sub_declarator);
   visitNodes(this, node->ptr_ops);
@@ -978,6 +1023,9 @@ void ContextBuilder::visitDeclarator(DeclaratorAST *node) {
   visit(node->bit_expression);
   //END Finished with first part of default visitor
 
+  if(m_onlyComputeSimplified)
+    return;
+
   createTypeForDeclarator(node);
   
   if(m_currentInitializer) //Needs to be visited now, so the type-builder can use the initializer to build a constant integral tyoe
