@@ -483,7 +483,7 @@ T* DeclarationBuilder::openDeclarationReal(NameAST* name, AST* rangeNode, const
 #endif
 
     ///@todo maybe order the declarations within ducontext and change here back to walking the indices, because that's easier to debug and faster
-    QList<Declaration*> decls = currentContext()->allLocalDeclarations(localId);
+    QList<Declaration*> decls = currentContext()->findLocalDeclarations(localId, SimpleCursor::invalid(), 0, AbstractType::Ptr(), DUContext::NoFiltering);
     foreach( Declaration* dec, decls ) {
 
       if( wasEncountered(dec) )
@@ -1131,15 +1131,15 @@ QualifiedIdentifier DeclarationBuilder::resolveNamespaceIdentifier(const Qualifi
     //Failed to resolve namespace
     kDebug(9007) << "Failed to resolve namespace \"" << identifier << "\"";
     QualifiedIdentifier ret = identifier;
-    ret.setExplicitlyGlobal(true);
+    ret.setExplicitlyGlobal(false);
     Q_ASSERT(ret.count());
     return ret;
   } else {
     QualifiedIdentifier ret = contexts.first()->scopeIdentifier(true);
+    ret.setExplicitlyGlobal(false);
     if(ret.isEmpty())
         return ret;
     Q_ASSERT(ret.count());
-    ret.setExplicitlyGlobal(true);
     return ret;
   }
 }
@@ -1163,6 +1163,11 @@ void DeclarationBuilder::visitUsing(UsingAST * node)
     }else{
       kDebug(9007) << "Aliased declaration not found:" << id.toString();
     }
+
+    if(m_accessPolicyStack.isEmpty())
+      decl->setAccessPolicy(KDevelop::Declaration::Public);
+    else
+      decl->setAccessPolicy(currentAccessPolicy());
   }
 
   closeDeclaration();
