@@ -63,6 +63,7 @@
 #include <language/duchain/duchainutils.h>
 #include "includepathcomputer.h"
 #include <interfaces/iuicontroller.h>
+#include <cpppreprocessenvironment.h>
 
 //#define DUMP_SMART_RANGES
 //#define DUMP_AST
@@ -229,8 +230,39 @@ const KUrl::List& CPPParseJob::includePathUrls() const {
   return masterJob()->m_includePathUrls;
 }
 
+void CPPParseJob::mergeDefines(CppPreprocessEnvironment& env) const
+{
+  //m_includePathsComputed is filled when includePaths() is called
+  masterJob()->includePaths();
+  
+  if(ICore::self()->shuttingDown())
+    return; //If the system is shutting down, include-paths were not computed properly
+  
+  Q_ASSERT(masterJob()->m_includePathsComputed);
+  
+  QHash<QString, QString> defines = masterJob()->m_includePathsComputed->defines();
+  
+  ///@todo Most probably, the same macro-sets will be calculated again and again.
+  ///           One ReferenceCountedMacroSet would be enough.
+  
+  kDebug() << "DEFINES:" << defines;
+  
+  for(QHash<QString, QString>::const_iterator it = defines.constBegin(); it != defines.constEnd(); ++it)
+  {
+    rpp::pp_macro* m = new rpp::pp_macro(IndexedString(it.key()));
+    m->setDefinitionText( *it );
+    
+    //Call rpp::Environment::setMacro directly, so we don't add the macro to the environment-file.
+    //It should be only part of the environment.
+    env.rpp::Environment::setMacro(m);
+  }
+}
+
 const QList<IndexedString>& CPPParseJob::includePaths() const {
     //If a lock was held here, we would get deadlocks
+    if( ICore::self()->shuttingDown() )
+      return QList<IndexedString>();
+    
     if( masterJob() == this ) {
         if( !m_includePathsComputed ) {
             Q_ASSERT(!DUChain::lock()->currentThreadHasReadLock() && !DUChain::lock()->currentThreadHasWriteLock());
@@ -238,7 +270,13 @@ const QList<IndexedString>& CPPParseJob::includePaths() const {
             qRegisterMetaType<CPPParseJob*>("CPPParseJob*");
             QMetaObject::invokeMethod(cpp(), "findIncludePathsForJob", Qt::QueuedConnection, Q_ARG(CPPParseJob*, const_cast<CPPParseJob*>(this)));
             //Will be woken once the include-paths are computed
-            m_waitForIncludePaths.wait(&m_waitForIncludePathsMutex);
+            while(!m_waitForIncludePaths.wait(&m_waitForIncludePathsMutex, 1000))
+            {
+              if(ICore::self()->shuttingDown())
+              {
+                return QList<IndexedString>();
+              }
+            }
             m_waitForIncludePathsMutex.unlock();
             Q_ASSERT(m_includePathsComputed);
             m_includePathsComputed->computeBackground();
@@ -549,7 +587,7 @@ void CPPInternalParseJob::run()
         ast = parser.parse( parentJob()->parseSession().data() );
 
         //This will be set to true if the duchain data should be left untouched
-        if(ast->hadMissingCompoundTokens && updatingContentContext) {
+        if((ast->hadMissingCompoundTokens || control.hasProblem(KDevelop::ProblemData::Lexer)) && updatingContentContext) {
           //Make sure we don't update into a completely invalid state where everything is invalidated temporarily.
           DUChainWriteLocker l(DUChain::lock());
 
