@@ -58,6 +58,21 @@ using namespace KDevelop;
 namespace CppUtils
 {
   
+int findEndOfInclude(QString line)
+{
+  QString tmp = line;
+  tmp = tmp.trimmed();
+  if(!tmp.startsWith("#"))
+    return -1;
+  
+  tmp = tmp.mid(1).trimmed();
+
+  if(!tmp.startsWith("include"))
+    return -1;
+  
+  return line.indexOf("include") + 7;
+}
+
 KUrl sourceOrHeaderCandidate( const KUrl &url, bool fast )
 {
   QString urlPath = url.toLocalFile(); ///@todo Make this work with real urls
@@ -168,26 +183,14 @@ bool isHeader(const KUrl &url) {
 
 QStringList standardIncludePaths()
 {
-  static QStringList list;
-  static bool init = false;
-  
-  if(!init) {
-    init = true;
-    CppTools::setupStandardIncludePaths(list);
-  }
+  static QStringList list = CppTools::setupStandardIncludePaths();
   return list;
 }
 
 
 const Cpp::ReferenceCountedMacroSet& standardMacros()
 {
-  static Cpp::ReferenceCountedMacroSet macros;
-  static bool init = false;
-  
-  if(!init)
-    // Retrieve the standard include paths & macro definitions for this machine.
-    // Uses gcc commands to retrieve the information.
-    CppTools::setupStandardMacros(macros);
+  static Cpp::ReferenceCountedMacroSet macros = CppTools::setupStandardMacros();
   return macros;
 }
 
