@@ -31,6 +31,7 @@
 using namespace KDevelop;
 
 #define DEBUG_INCLUDE_PATHS 1
+const bool enableIncludePathResolution = true;
 
 QList<KUrl> convertToUrls(const QList<IndexedString>& stringList) {
   QList<KUrl> ret;
@@ -79,7 +80,6 @@ void IncludePathComputer::computeForeground() {
             continue;
         }
 
-
         m_projectName = project->name();
         m_projectDirectory = project->folder();
         m_effectiveBuildDirectory = m_buildDirectory = buildManager->buildDirectory(project->projectItem());
@@ -90,6 +90,8 @@ void IncludePathComputer::computeForeground() {
 
         KUrl::List dirs = buildManager->includeDirectories(file);
 
+        m_defines = buildManager->defines(file);
+        
         m_gotPathsFromManager = true;
 
         kDebug(9007) << "Got " << dirs.count() << " include-paths from build-manager";
@@ -120,11 +122,9 @@ void IncludePathComputer::computeBackground() {
     m_includePathDependency = m_includeResolver.findIncludePathDependency(m_source.toLocalFile());
     kDebug() << "current include path dependency state:" << m_includePathDependency.toString();
     
+    ///@todo Resolve include-paths either once per directory, or once per target. Do not iterate over the duchain.
+    
     if(!m_ready) {
-    ///@todo Make modification-revisions dependent also on Makefiles, and on custom include paths files, so when those are changed, the files
-    ///           are marked for update.
-    ///           If there is no valid include-path dependency while custom include-paths are set no, do not do this.
-      
       //Try taking the include-paths from another file in the directory
       kDebug(9007) << "Did not get any include-paths for" << m_source;
       QFileInfo fileInfo(m_source.toLocalFile());
@@ -164,7 +164,7 @@ void IncludePathComputer::computeBackground() {
     
     KDevelop::ProblemPointer problem(new KDevelop::Problem);
 
-    if( m_ret.isEmpty() || DEBUG_INCLUDE_PATHS ) {
+    if( (m_ret.isEmpty() || DEBUG_INCLUDE_PATHS) && enableIncludePathResolution ) {
         //Fallback-search using include-path resolver
 
         if(!m_effectiveBuildDirectory.isEmpty()) {
