@@ -35,7 +35,6 @@
 ParseSession::ParseSession()
   : mempool(new pool)
   , token_stream(0)
-  , macros(0)
   , m_locationTable(0)
   , m_topAstNode(0)
 {
@@ -46,7 +45,6 @@ ParseSession::~ParseSession()
   delete mempool;
   delete token_stream;
   delete m_locationTable;
-  delete macros;
 }
 
 TranslationUnitAST * ParseSession::topAstNode(void)
@@ -79,7 +77,7 @@ void ParseSession::mapAstDuChain (AST * node , KDevelop::DeclarationPointer decl
 void ParseSession::mapAstUse(AST *node, const SimpleUse& use)
 {
   //Duplicates shouldn't exist(? Same for uses?)
-  if(m_AstToUse.find(node) == m_AstToUse.end() || m_AstToUse[node] != use)
+  if(m_AstToUse.contains(node) && m_AstToUse[node] != use)
     kWarning() << "Found dupplicate use mapping for node" << node;
 
   m_AstToUse[node] = use;
