@@ -300,7 +300,6 @@ KDevelop::ProjectFolderItem* CMakeManager::import( KDevelop::IProject *project )
             }
         }
 
-        m_watchers[project] = new KDirWatch(project);
         m_rootItem = new CMakeFolderItem(project, folderUrl.url(), 0 );
         m_rootItem->setProjectRoot(true);
 
@@ -310,7 +309,9 @@ KDevelop::ProjectFolderItem* CMakeManager::import( KDevelop::IProject *project )
         }
         cachefile.addPath("CMakeCache.txt");
         m_projectCache[project]=readCache(cachefile);
-
+        
+        m_watchers[project] = new KDirWatch(project);
+        m_watchers[project]->addDir(folderUrl.path());
         m_watchers[project]->disconnect( SIGNAL(dirty(QString) ), this, SLOT(dirtyFile(QString)));
         connect(m_watchers[project], SIGNAL(dirty(QString)), this, SLOT(dirtyFile(QString)));
         Q_ASSERT(m_rootItem->rowCount()==0);
@@ -326,10 +327,9 @@ KDevelop::ReferencedTopDUContext CMakeManager::includeScript(const QString& file
     return CMakeParserUtils::includeScript( file, parent, &m_varsPerProject[project], &m_macrosPerProject[project], project->folder().toLocalFile(KUrl::RemoveTrailingSlash), &m_projectCache[project], m_modulePathPerProject[project]);
 }
 
-QSet<QString> removeMatches(const QString& exp, const QStringList& orig)
+QSet<QString> removeMatches(const QRegExp& rx, const QStringList& orig)
 {
     QSet<QString> ret;
-    QRegExp rx(exp);
     foreach(const QString& str, orig)
     {
         if(rx.indexIn(str)<0)
@@ -338,14 +338,15 @@ QSet<QString> removeMatches(const QString& exp, const QStringList& orig)
     return ret;
 }
 
+
+static QRegExp rxFileFilter("\\w*~$|\\w*\\.bak$");
 QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolderItem* item )
 {
     QList<KDevelop::ProjectFolderItem*> folderList;
     CMakeFolderItem* folder = dynamic_cast<CMakeFolderItem*>( item );
 
-    QStringList entriesL = QDir( item->url().toLocalFile() ).entryList( QDir::AllEntries | QDir::NoDotAndDotDot );
-    QSet<QString> entries = removeMatches("\\w*~$|\\w*\\.bak$", entriesL);
     KUrl subroot=item->project()->folder();
+    m_watchers[item->project()]->addDir(item->url().toLocalFile());
     if(folder && folder->type()==KDevelop::ProjectBaseItem::BuildFolder)
     {
         Q_ASSERT(folder->rowCount()==0);
@@ -455,7 +456,6 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
                 kDebug(9042) << "Found subdir " << path << "which should be into" << subroot;
                 if(subroot.isParentOf(path) || path.isParentOf(subroot))
                 {
-                    entries.remove(subf);
                     CMakeFolderItem* parent=folder;
                     if(path.upUrl()!=folder->url())
                         parent=0;
@@ -512,8 +512,8 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
             {
                 QStringList files=t.files;
                 QString outputName=t.name;
-                if(data.properties[TARGET].contains(t.name) && data.properties[TARGET][t.name].contains("OUTPUT_NAME"))
-                    outputName=data.properties[TARGET][t.name]["OUTPUT_NAME"].first();
+                if(data.properties[TargetProperty].contains(t.name) && data.properties[TargetProperty][t.name].contains("OUTPUT_NAME"))
+                    outputName=data.properties[TargetProperty][t.name]["OUTPUT_NAME"].first();
                 
                 QString path;
                 switch(t.type)
@@ -563,13 +563,6 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
                         sourceFile.addPath( sFile );
                     }
                     
-                    bool removed=entries.remove( sourceFile.fileName() );
-                    if(removed && folder->url()==sourceFile.upUrl()) {
-                        //Even if a file is inside 2 targets we do not want to have it
-                        //2 times on the folder.
-                        new KDevelop::ProjectFileItem( item->project(), sourceFile, folder );
-                    }
-
                     new KDevelop::ProjectFileItem( item->project(), sourceFile, targetItem );
                     item->project()->addToFileSet( KDevelop::IndexedString( sourceFile ) );
                     kDebug(9042) << "..........Adding:" << sourceFile;
@@ -579,6 +572,8 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
         }
     }
 
+    QStringList entriesL = QDir( item->url().toLocalFile() ).entryList( QDir::AllEntries | QDir::NoDotAndDotDot );
+    QSet<QString> entries = removeMatches(rxFileFilter, entriesL);
     foreach( const QString& entry, entries )
     {
         if( item->hasFileOrFolder( entry ) )
@@ -595,8 +590,9 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
             if(!QFile::exists(cache.toLocalFile())
                 && !CMake::allBuildDirs(item->project()).contains(fileurl.toLocalFile(KUrl::RemoveTrailingSlash)))
             {
-                if(m_pending.contains(fileurl))
-                    item->appendRow(m_pending.take(fileurl));
+                ProjectFolderItem* folderItem=m_pending.take(fileurl);
+                if(folderItem)
+                    item->appendRow(folderItem);
                 else
                 {
                     ProjectFolderItem* fitem=new ProjectFolderItem( item->project(), fileurl, item );
@@ -618,25 +614,28 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
     return folderList;
 }
 
-bool CMakeManager::reload(KDevelop::ProjectBaseItem* it)
+bool CMakeManager::reload(KDevelop::ProjectFolderItem* folder)
 {
-    CMakeFolderItem* item=dynamic_cast<CMakeFolderItem*>(it->folder());
-    while(!item && it->parent()) {
-        it=dynamic_cast<ProjectBaseItem*>(it->parent());
-        item=dynamic_cast<CMakeFolderItem*>(it->folder());
+    CMakeFolderItem* item=dynamic_cast<CMakeFolderItem*>(folder);
+    if ( !item ) {
+        QStandardItem* it = folder;
+        while(!item && it->parent()) {
+            it = it->parent();
+            item = dynamic_cast<CMakeFolderItem*>(it);
+        }
     }
-    
-    if (!item || it == it->project()->projectItem()) {
-        it->project()->reloadModel();
+
+    if (!item || item == item->project()->projectItem()) {
+        folder->project()->reloadModel();
     } else {
         CMakeFolderItem* former=item->formerParent();
         QStandardItem* parent=item->parent();
         KUrl url=item->url();
         IProject* project=item->project();
-        
-        item->parent()->removeRow(item->row());
+
+        parent->removeRow(item->row());
         CMakeFolderItem* fi=new CMakeFolderItem(project, url.toLocalFile(), 0);
-                                                    
+
         fi->setFormerParent(former);
         parent->appendRow(fi);
         reimport(fi);
@@ -797,7 +796,7 @@ void CMakeManager::dirtyFile(const QString & dirty)
             reload(proj->projectItem());
         }
     }
-    else
+    else if(dirty.endsWith(".cmake"))
     {
         foreach(KDevelop::IProject* project, m_watchers.uniqueKeys())
         {
@@ -805,6 +804,80 @@ void CMakeManager::dirtyFile(const QString & dirty)
                 reload(project->projectItem());
         }
     }
+    else if(QFileInfo(dirty).isDir())
+    {
+        foreach(KDevelop::IProject* project, m_watchers.uniqueKeys())
+        {
+            QList<ProjectFolderItem*> folders=project->foldersForUrl(dirty);
+            Q_ASSERT(folders.isEmpty() || folders.size()==1);
+            
+            QStringList entriesL = QDir(dirty).entryList( QDir::AllEntries | QDir::NoDotAndDotDot );
+            QSet<QString> entries = removeMatches(rxFileFilter, entriesL);
+            
+            if(!folders.isEmpty())
+            {
+                ProjectFolderItem* item=folders.first();
+                KUrl folderurl = item->url();
+                
+                //We look for new elements
+                foreach( const QString& entry, entries )
+                {
+                    if( item->hasFileOrFolder( entry ) )
+                        continue;
+
+                    KUrl fileurl = folderurl;
+                    fileurl.addPath( entry );
+
+                    if( QFileInfo( fileurl.toLocalFile() ).isDir() )
+                    {
+                        KUrl cache=fileurl;
+                        cache.addPath("CMakeCache.txt");
+                        fileurl.adjustPath(KUrl::AddTrailingSlash);
+                        if(!QFile::exists(cache.toLocalFile())
+                            && !CMake::allBuildDirs(item->project()).contains(fileurl.toLocalFile(KUrl::RemoveTrailingSlash)))
+                        {
+                            new ProjectFolderItem( item->project(), fileurl, item );    
+                        }
+                    }
+                    else
+                    {
+                        addFile(fileurl, item);
+                    }
+                }
+                
+                //We look for removed elements
+                for(int i=0; i<item->rowCount(); i++)
+                {
+                    QStandardItem* it=item->child(i, 0);
+                    if(it->type()==ProjectBaseItem::Target)
+                        continue;
+                    
+                    QString current=it->text();
+                    if(!entries.contains(current))
+                    {
+                        KUrl fileurl = folderurl;
+                        fileurl.addPath(current);
+                    
+                        switch(it->type())
+                        {
+                            case ProjectBaseItem::File:
+                                foreach(const ProjectFileItem* removed, p->filesForUrl(fileurl))
+                                    removed->parent()->removeRow(removed->row());
+                                p->removeFromFileSet(IndexedString(fileurl));
+                                break;
+                            case ProjectBaseItem::Folder:
+                            case ProjectBaseItem::BuildFolder:
+                                foreach(const ProjectFolderItem* removed, p->foldersForUrl(fileurl))
+                                    removed->parent()->removeRow(removed->row());
+                                break;
+                            default:
+                                break;
+                        }
+                    }
+                }
+            }
+        }
+    }
 }
 
 QList< KDevelop::ProjectTargetItem * > CMakeManager::targets(KDevelop::ProjectFolderItem * folder) const
@@ -1039,16 +1112,22 @@ bool followUses(KTextEditor::Document* doc, SimpleRange r, const QString& name,
 bool CMakeManager::removeFile( KDevelop::ProjectFileItem* it)
 {
     bool ret=true;
-    if(!static_cast<ProjectBaseItem*>(it->parent())->target())
+    it->project()->removeFromFileSet(KDevelop::IndexedString(it->url()));
+    
+    QList<ProjectFileItem*> files=it->project()->filesForUrl(it->url());
+    QList<ProjectTargetItem*> targets;
+
+    //We loop through all the files with the same url
+    foreach(ProjectFileItem* file, files)
     {
-        it->project()->removeFromFileSet(KDevelop::IndexedString( it->url()));
-        it->parent()->removeRow(it->row());
-    }
-    else
-    {
-        ProjectTargetItem* target=static_cast<ProjectTargetItem*>(it->parent());
-        ret = removeFileFromTarget(it, target);
+        ProjectTargetItem* target=static_cast<ProjectBaseItem*>(file->parent())->target();
+        if(target) {
+            bool res = removeFileFromTarget(file, target);
+            ret = ret && res;
+        } else
+            file->parent()->removeRow(file->row());
     }
+
     return ret;
 }
 
@@ -1077,18 +1156,11 @@ bool CMakeManager::removeFileFromTarget( KDevelop::ProjectFileItem* it, KDevelop
         if(e.exec())
         {
             bool saved=e.applyAllChanges();
-            if(!saved)
-                KMessageBox::error(0, i18n("KDevelop - CMake Support"),
-                                    i18n("Cannot save the change."));
-            else
+            if(saved)
                 it->project()->removeFromFileSet(IndexedString(it->url()));
         }
     }
-    else
-    {
-        KMessageBox::error(0, i18n("KDevelop - CMake Support"),
-                              i18n("Cannot remove the file."));
-    }
+    
     return ret;
 }
 
@@ -1107,9 +1179,7 @@ bool CMakeManager::addFileToTarget( KDevelop::ProjectFileItem* it, KDevelop::Pro
     QSet<QString> headerExt=QSet<QString>() << ".h" << ".hpp" << ".hxx";
     foreach(const QString& ext, headerExt)
     {
-        if(it->url().fileName().endsWith(ext))
-            return false;
-        else if(it->url().fileName().endsWith(ext.toUpper()))
+        if(it->url().fileName().toLower().endsWith(ext))
             return false;
     }
     
@@ -1130,7 +1200,10 @@ bool CMakeManager::addFileToTarget( KDevelop::ProjectFileItem* it, KDevelop::Pro
     e.setInformation(i18n("Add a file called '%1' to target '%2'.", it->fileName(), target->text()));
     e.addDocuments(IndexedString(lists), IndexedString(lists));
 
-    bool ret=followUses(e.document(), r, ' '+it->fileName(), lists, true, QString());
+    QString filename=KUrl::relativeUrl(folder->url(), it->url());
+    if(filename.startsWith("./"))
+        filename=filename.right(filename.size()-2);
+    bool ret=followUses(e.document(), r, ' '+filename, lists, true, QString());
 
     if(ret && e.exec())
         ret=e.applyAllChanges();
@@ -1208,55 +1281,67 @@ QPair<QString, QString> CMakeManager::cacheValue(KDevelop::IProject* project, co
 
 bool CMakeManager::renameFile(ProjectFileItem* it, const KUrl& newUrl)
 {
-    ProjectTargetItem* target=static_cast<ProjectBaseItem*>(it->parent())->target();
-    if(!target) {
+    QList<ProjectFileItem*> files=it->project()->filesForUrl(it->url());
+    
+    QList<ProjectTargetItem*> targets;
+    
+    //We loop through all the files with the same url
+    foreach(ProjectFileItem* file, files)
+    {
+        ProjectTargetItem* t=static_cast<ProjectBaseItem*>(file->parent())->target();
+        if(t)
+            targets+=t;
+        else
+            file->setUrl(newUrl);
+    }
+        
+    if(targets.isEmpty())
+    {
         KIO::CopyJob* job=KIO::move(it->url(), newUrl);
-        qDebug() << "pssss" << it->url() << "->" << newUrl;
+        kDebug() << "rename" << it->url() << "->" << newUrl;
         bool ret=KIO::NetAccess::synchronousRun(job, 0);
         
         if(ret) {
             it->project()->removeFromFileSet(IndexedString(it->url()));
-            it->setUrl(newUrl);
-            it->project()->addToFileSet(IndexedString(it->url()));
+            it->project()->addToFileSet(IndexedString(newUrl));
         }
         return ret;
     }
     
-    CMakeFolderItem* folder=static_cast<CMakeFolderItem*>(target->parent());
-
-    DescriptorAttatched* desc=dynamic_cast<DescriptorAttatched*>(target);
-    SimpleRange r=desc->descriptor().range();
-    r.start=SimpleCursor(desc->descriptor().arguments.first().range().end);
-
-    KUrl lists=folder->url();
-    lists.addPath("CMakeLists.txt");
-    
-    QString newName=KUrl::relativePath(it->url().upUrl().path(), newUrl.path());
-    if(newName.startsWith("./"))
-        newName.remove(0,2);
-
     ApplyChangesWidget e;
     e.setCaption(it->text());
     e.setInformation(i18n("Remove a file called '%1'.", it->text()));
-    e.addDocuments(IndexedString(lists), IndexedString(lists));
+    
+    bool ret=false;
+    foreach(ProjectTargetItem* target, targets)
+    {
+        CMakeFolderItem* folder=static_cast<CMakeFolderItem*>(target->parent());
+
+        DescriptorAttatched* desc=dynamic_cast<DescriptorAttatched*>(target);
+        SimpleRange r=desc->descriptor().range();
+        r.start=SimpleCursor(desc->descriptor().arguments.first().range().end);
+
+        KUrl lists=folder->url();
+        lists.addPath("CMakeLists.txt");
+        e.addDocuments(IndexedString(lists), IndexedString(lists));
+        
+        QString newName=KUrl::relativePath(it->url().upUrl().path(), newUrl.path());
+        if(newName.startsWith("./"))
+            newName.remove(0,2);
+        bool hasChanges = followUses(e.document(), r, ' '+it->text(), lists, false, ' '+newName);
+        ret = ret || hasChanges;
+    }
 
-    bool ret=followUses(e.document(), r, ' '+it->text(), lists, false, ' '+newName);
     if(ret && e.exec())
     {
+        it->project()->removeFromFileSet(IndexedString(it->url()));
+        KIO::CopyJob* job=KIO::move(it->url(), newUrl);
         ret=e.applyAllChanges();
         
         if(ret)
-        {
-            KIO::CopyJob* job=KIO::move(it->url(), newUrl);
-            bool ret=KIO::NetAccess::synchronousRun(job, 0);
-            
-            if(ret)
-            {
-                it->project()->removeFromFileSet(IndexedString(it->url()));
-                it->setUrl(newUrl);
-                it->project()->addToFileSet(IndexedString(it->url()));
-            }
-        }
+            ret=KIO::NetAccess::synchronousRun(job, 0);
+        else
+            delete job;
     }
 
     return ret;
@@ -1295,18 +1380,15 @@ bool CMakeManager::renameFolder(ProjectFolderItem* _it, const KUrl& newUrl)
     bool ret=e.exec();
     if(ret)
     {
+        KIO::CopyJob* job=KIO::move(it->url(), newUrl);
         ret=e.applyAllChanges();
         
-        if(ret) {
-            KIO::CopyJob* job=KIO::move(it->url(), newUrl);
+        if(ret)
             ret=KIO::NetAccess::synchronousRun(job, 0);
-            if(ret) {
-                it->setUrl(newUrl);
-            }
-        }
+        else
+            delete job;
     }
     return ret;
 }
 
-
 #include "cmakemanager.moc"
