@@ -81,7 +81,6 @@ public:
     virtual KUrl buildDirectory(KDevelop::ProjectBaseItem*) const;
     virtual KUrl::List includeDirectories(KDevelop::ProjectBaseItem *) const;
     virtual QHash<QString, QString> defines(KDevelop::ProjectBaseItem *) const;
-    virtual QHash<QString, QString> environment(KDevelop::ProjectBaseItem*) const { return QHash<QString,QString>(); }
 
     virtual KDevelop::ProjectFolderItem* addFolder( const KUrl& folder, KDevelop::ProjectFolderItem* parent );
     virtual KDevelop::ProjectFileItem* addFile( const KUrl&, KDevelop::ProjectFolderItem* );
@@ -102,7 +101,7 @@ public:
     virtual QList<KDevelop::ProjectFolderItem*> parse( KDevelop::ProjectFolderItem* dom );
     virtual KDevelop::ProjectFolderItem* import( KDevelop::IProject *project );
     
-    virtual bool reload(KDevelop::ProjectBaseItem*);
+    virtual bool reload(KDevelop::ProjectFolderItem*);
 
     KDevelop::ContextMenuExtension contextMenuExtension( KDevelop::Context* context );
     
@@ -121,7 +120,6 @@ public slots:
     void jumpToDeclaration();
 
 private:
-    void parseOnly(KDevelop::IProject* project, const KUrl &url);
     void reimport(CMakeFolderItem*);
     CacheValues readCache(const KUrl &path) const;
 
