@@ -24,7 +24,6 @@
 
 #include "cmakeast.h"
 
-#include <QRegExp>
 #include <QString>
 
 #include <KDebug>
@@ -115,10 +114,6 @@ CMAKE_REGISTER_AST( WhileAst, while)
 CMAKE_REGISTER_AST( WriteFileAst, write_file)
 
 
-void CMakeAst::writeBack(QString& ) const
-{
-}
-
 enum Stage {NAMES, PATHS, PATH_SUFFIXES, HINTS};
 
 CustomCommandAst::CustomCommandAst()
@@ -133,10 +128,6 @@ CustomCommandAst::~CustomCommandAst()
 {
 }
 
-void CustomCommandAst::writeBack( QString& /*buffer */ ) const
-{
-}
-
 bool CustomCommandAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != QLatin1String( "add_custom_command" )  )
@@ -270,10 +261,6 @@ CustomTargetAst::~CustomTargetAst()
 {
 }
 
-void CustomTargetAst::writeBack( QString& ) const
-{
-}
-
 bool CustomTargetAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != QLatin1String( "add_custom_target" ) )
@@ -384,10 +371,6 @@ AddDefinitionsAst::~AddDefinitionsAst()
 {
 }
 
-void AddDefinitionsAst::writeBack( QString& ) const
-{
-}
-
 bool AddDefinitionsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "add_definitions" )
@@ -414,10 +397,6 @@ AddDependenciesAst::~AddDependenciesAst()
 {
 }
 
-void AddDependenciesAst::writeBack( QString& ) const
-{
-}
-
 bool AddDependenciesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "add_dependencies" )
@@ -451,10 +430,6 @@ AddExecutableAst::~AddExecutableAst()
 {
 }
 
-void AddExecutableAst::writeBack( QString& ) const
-{
-}
-
 bool AddExecutableAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "add_executable" )
@@ -489,11 +464,17 @@ bool AddExecutableAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 
 }
 
+QMap<QString, AddLibraryAst::LibraryType> AddLibraryAst::s_typeForName;
 AddLibraryAst::AddLibraryAst()
 {
-    m_isShared = false;
-    m_isStatic = true;
-    m_isModule = false;
+    if(s_typeForName.isEmpty()) {
+        s_typeForName.insert("STATIC", Static);
+        s_typeForName.insert("SHARED", Shared);
+        s_typeForName.insert("MODULE", Module);
+        s_typeForName.insert("UNKNOWN", Unknown);
+    }
+    
+    m_type = Static;
     m_isImported = false;
     m_excludeFromAll = false;
 }
@@ -502,10 +483,6 @@ AddLibraryAst::~AddLibraryAst()
 {
 }
 
-void AddLibraryAst::writeBack( QString& ) const
-{
-}
-
 bool AddLibraryAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "add_library" || func.arguments.isEmpty() )
@@ -519,21 +496,9 @@ bool AddLibraryAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     ++it;
     for(; it != itEnd;)
     {
-        if ( it->value == "STATIC" && !libTypeSet )
+        if ( !libTypeSet && s_typeForName.contains(it->value) )
         {
-            m_isStatic = true;
-            libTypeSet = true;
-            ++it;
-        }
-        else if ( it->value == "SHARED" && !libTypeSet )
-        {
-            m_isShared = true;
-            libTypeSet = true;
-            ++it;
-        }
-        else if ( it->value == "MODULE" && !libTypeSet )
-        {
-            m_isModule = true;
+            m_type = s_typeForName.value(it->value);
             libTypeSet = true;
             ++it;
         }
@@ -573,10 +538,6 @@ AddSubdirectoryAst::~AddSubdirectoryAst()
 {
 }
 
-void AddSubdirectoryAst::writeBack( QString& ) const
-{
-}
-
 bool AddSubdirectoryAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "add_subdirectory" )
@@ -608,10 +569,6 @@ AddTestAst::~AddTestAst()
 {
 }
 
-void AddTestAst::writeBack( QString& ) const
-{
-}
-
 bool AddTestAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "add_test" )
@@ -637,10 +594,6 @@ AuxSourceDirectoryAst::~AuxSourceDirectoryAst()
 {
 }
 
-void AuxSourceDirectoryAst::writeBack( QString& ) const
-{
-}
-
 bool AuxSourceDirectoryAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "aux_source_directory" )
@@ -663,10 +616,6 @@ BuildCommandAst::~BuildCommandAst()
 {
 }
 
-void BuildCommandAst::writeBack( QString& ) const
-{
-}
-
 bool BuildCommandAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "build_command" )
@@ -689,10 +638,6 @@ BuildNameAst::~BuildNameAst()
 {
 }
 
-void BuildNameAst::writeBack( QString& ) const
-{
-}
-
 bool BuildNameAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "build_name" )
@@ -714,10 +659,6 @@ CMakeMinimumRequiredAst::~CMakeMinimumRequiredAst()
 {
 }
 
-void CMakeMinimumRequiredAst::writeBack( QString& ) const
-{
-}
-
 bool CMakeMinimumRequiredAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if ( func.name.toLower() != "cmake_minimum_required" )
@@ -748,9 +689,6 @@ ConfigureFileAst::~ConfigureFileAst()
 {
 }
 
-void ConfigureFileAst::writeBack( QString& ) const
-{
-}
 
 bool ConfigureFileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -790,9 +728,6 @@ CreateTestSourcelistAst::~CreateTestSourcelistAst()
 {
 }
 
-void CreateTestSourcelistAst::writeBack( QString& ) const
-{
-}
 
 bool CreateTestSourcelistAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -840,9 +775,6 @@ EnableLanguageAst::~EnableLanguageAst()
 {
 }
 
-void EnableLanguageAst::writeBack( QString& ) const
-{
-}
 
 bool EnableLanguageAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -867,9 +799,6 @@ EnableTestingAst::~EnableTestingAst()
 {
 }
 
-void EnableTestingAst::writeBack( QString& ) const
-{
-}
 
 bool EnableTestingAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -884,9 +813,6 @@ ExecProgramAst::~ExecProgramAst()
 {
 }
 
-void ExecProgramAst::writeBack( QString& ) const
-{
-}
 
 bool ExecProgramAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -943,9 +869,6 @@ ExecuteProcessAst::~ExecuteProcessAst()
 {
 }
 
-void ExecuteProcessAst::writeBack( QString& ) const
-{
-}
 
 bool ExecuteProcessAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1058,9 +981,6 @@ ExportLibraryDepsAst::~ExportLibraryDepsAst()
 {
 }
 
-void ExportLibraryDepsAst::writeBack( QString& ) const
-{
-}
 
 bool ExportLibraryDepsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1088,9 +1008,6 @@ FileAst::~FileAst()
 {
 }
 
-void FileAst::writeBack( QString& ) const
-{
-}
 
 bool FileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1100,43 +1017,43 @@ bool FileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     QString type = func.arguments.first().value;
     int min_args=-1;
     if(type=="WRITE") {
-       m_type = WRITE;
+       m_type = Write;
        min_args=3;
     } else if(type=="APPEND") {
-        m_type = APPEND;
+        m_type = Append;
         min_args=3;
     } else if(type=="READ") {
-        m_type = READ;
+        m_type = Read;
         min_args=3;
     } else if(type=="GLOB") {
-        m_type = GLOB;
+        m_type = Glob;
         min_args=3;
     } else if(type=="GLOB_RECURSE") {
-        m_type = GLOB_RECURSE;
+        m_type = GlobRecurse;
         min_args = 3;
     } else if(type=="REMOVE") {
-        m_type = REMOVE;
+        m_type = Remove;
         min_args=2;
     } else if(type=="REMOVE_RECURSE") {
-        m_type = REMOVE_RECURSE;
+        m_type = RemoveRecurse;
         min_args=2;
     } else if(type=="MAKE_DIRECTORY") {
-        m_type = MAKE_DIRECTORY;
+        m_type = MakeDirectory;
         min_args=2;
     } else if(type=="RELATIVE_PATH") {
-        m_type = RELATIVE_PATH;
+        m_type = RelativePath;
         min_args=4;
     } else if(type=="TO_CMAKE_PATH") {
-        m_type = TO_CMAKE_PATH;
+        m_type = ToCmakePath;
         min_args=3;
     } else if(type=="TO_NATIVE_PATH") {
-        m_type = TO_NATIVE_PATH;
+        m_type = ToNativePath;
         min_args=3;
     } else if(type=="STRINGS") {
-        m_type = STRINGS;
+        m_type = Strings;
         min_args=3;
     } else if(type=="DOWNLOADS") {
-        m_type = DOWNLOAD;
+        m_type = Download;
         min_args=3;
     } else
         return false;
@@ -1146,18 +1063,18 @@ bool FileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 
     QList<CMakeFunctionArgument>::const_iterator it, itEnd;
     switch(m_type) {
-        case WRITE:
-        case APPEND:
+        case Write:
+        case Append:
             m_path = func.arguments[1].value;
             m_message = func.arguments[2].value;
             break;
-        case READ:
+        case Read:
             m_path=func.arguments[1].value;
             m_variable = func.arguments[2].value;
             addOutputArgument(func.arguments[2]);
             break;
-        case GLOB:
-        case GLOB_RECURSE:
+        case Glob:
+        case GlobRecurse:
             addOutputArgument(func.arguments[1]);
             m_variable = func.arguments[1].value;
             it=func.arguments.constBegin()+2;
@@ -1174,28 +1091,28 @@ bool FileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                     m_globbingExpressions << it->value;
             }
             break;
-        case REMOVE:
-        case REMOVE_RECURSE:
-        case MAKE_DIRECTORY:
+        case Remove:
+        case RemoveRecurse:
+        case MakeDirectory:
             it=func.arguments.constBegin()+1;
             itEnd=func.arguments.constEnd();
             
             for(; it!=itEnd; ++it)
                 m_directories << it->value;
             break;
-        case RELATIVE_PATH:
+        case RelativePath:
             addOutputArgument(func.arguments[1]);
             m_variable = func.arguments[1].value;
             m_directory = func.arguments[2].value;
             m_path = func.arguments[3].value;
             break;
-        case TO_CMAKE_PATH:
-        case TO_NATIVE_PATH:
+        case ToCmakePath:
+        case ToNativePath:
             addOutputArgument(func.arguments[2]);
             m_path = func.arguments[1].value;
             m_variable = func.arguments[2].value;
             break;
-        case DOWNLOAD:
+        case Download:
             m_url=func.arguments[1].value;
             m_path=func.arguments[2].value;
             it=func.arguments.constBegin()+3;
@@ -1216,7 +1133,7 @@ bool FileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 }
             }
             break;
-        case STRINGS:
+        case Strings:
             m_path=func.arguments[1].value;
             m_variable=func.arguments[2].value;
             it=func.arguments.constBegin()+3;
@@ -1288,9 +1205,6 @@ FindFileAst::~FindFileAst()
 {
 }
 
-void FindFileAst::writeBack( QString& ) const
-{
-}
 
 bool FindFileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1357,9 +1271,6 @@ MacroCallAst::~MacroCallAst()
 {
 }
 
-void MacroCallAst::writeBack( QString& ) const
-{
-}
 
 bool MacroCallAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1383,9 +1294,6 @@ FindLibraryAst::~FindLibraryAst()
 {
 }
 
-void FindLibraryAst::writeBack( QString& ) const
-{
-}
 
 bool FindLibraryAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1453,9 +1361,6 @@ FindPackageAst::~FindPackageAst()
 {
 }
 
-void FindPackageAst::writeBack( QString& ) const
-{
-}
 
 bool FindPackageAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1503,9 +1408,6 @@ FindPathAst::~FindPathAst()
 {
 }
 
-void FindPathAst::writeBack( QString& ) const
-{
-}
 
 bool FindPathAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1576,9 +1478,6 @@ FindProgramAst::~FindProgramAst()
 {
 }
 
-void FindProgramAst::writeBack( QString& ) const
-{
-}
 
 bool FindProgramAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1645,9 +1544,6 @@ FltkWrapUiAst::~FltkWrapUiAst()
 {
 }
 
-void FltkWrapUiAst::writeBack( QString& ) const
-{
-}
 
 bool FltkWrapUiAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1663,9 +1559,6 @@ ForeachAst::~ForeachAst()
 {
 }
 
-void ForeachAst::writeBack( QString& ) const
-{
-}
 
 bool ForeachAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1711,9 +1604,6 @@ GetCMakePropertyAst::~GetCMakePropertyAst()
 {
 }
 
-void GetCMakePropertyAst::writeBack( QString& ) const
-{
-}
 
 bool GetCMakePropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1724,13 +1614,13 @@ bool GetCMakePropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     
     QString type=func.arguments[1].value.toUpper();
     if(type=="VARIABLES")
-        m_type=VARIABLES;
+        m_type=Variables;
     else if(type=="CACHE_VARIABLES")
-        m_type=CACHE_VARIABLES;
+        m_type=CacheVariables;
     else if(type=="COMMANDS")
-        m_type=COMMANDS;
+        m_type=Commands;
     else if(type=="MACROS")
-        m_type=MACROS;
+        m_type=Macros;
     else
         return false;
     return true;
@@ -1744,9 +1634,6 @@ GetDirPropertyAst::~GetDirPropertyAst()
 {
 }
 
-void GetDirPropertyAst::writeBack( QString& ) const
-{
-}
 
 bool GetDirPropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1774,9 +1661,6 @@ GetFilenameComponentAst::~GetFilenameComponentAst()
 {
 }
 
-void GetFilenameComponentAst::writeBack( QString& ) const
-{
-}
 
 bool GetFilenameComponentAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1787,16 +1671,16 @@ bool GetFilenameComponentAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     m_fileName = func.arguments[1].value;
     QString t = func.arguments[2].value;
     
-    if(t=="PATH") m_type=PATH;
-    else if(t=="ABSOLUTE") m_type=ABSOLUTE;
-    else if(t=="NAME") m_type=NAME;
-    else if(t=="EXT") m_type=EXT;
-    else if(t=="NAME_WE") m_type=NAME_WE;
-    else if(t=="PROGRAM") m_type=PROGRAM;
+    if(t=="PATH") m_type=Path;
+    else if(t=="ABSOLUTE") m_type=Absolute;
+    else if(t=="NAME") m_type=Name;
+    else if(t=="EXT") m_type=Ext;
+    else if(t=="NAME_WE") m_type=NameWe;
+    else if(t=="PROGRAM") m_type=Program;
     else
         return false;
     
-    if(m_type==PROGRAM) {
+    if(m_type==Program) {
         //TODO: Did not understand this option
     }
     
@@ -1812,9 +1696,6 @@ GetSourceFilePropAst::~GetSourceFilePropAst()
 {
 }
 
-void GetSourceFilePropAst::writeBack( QString& ) const
-{
-}
 
 bool GetSourceFilePropAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1835,9 +1716,6 @@ GetTargetPropAst::~GetTargetPropAst()
 {
 }
 
-void GetTargetPropAst::writeBack( QString& ) const
-{
-}
 
 bool GetTargetPropAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1858,9 +1736,6 @@ GetTestPropAst::~GetTestPropAst()
 {
 }
 
-void GetTestPropAst::writeBack( QString& ) const
-{
-}
 
 bool GetTestPropAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1881,11 +1756,6 @@ IfAst::~IfAst()
 {
 }
 
-void IfAst::writeBack( QString& s) const
-{
-    kDebug(9032)<< "if:" << s;
-}
-
 bool IfAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if(func.name.toLower()!="if" && func.name.toLower()!="elseif" && func.name.toLower()!="else")
@@ -1911,9 +1781,6 @@ IncludeAst::~IncludeAst()
 {
 }
 
-void IncludeAst::writeBack( QString& ) const
-{
-}
 
 bool IncludeAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1951,9 +1818,6 @@ IncludeDirectoriesAst::~IncludeDirectoriesAst()
 {
 }
 
-void IncludeDirectoriesAst::writeBack( QString& ) const
-{
-}
 
 bool IncludeDirectoriesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -1961,20 +1825,20 @@ bool IncludeDirectoriesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
         return false;
     
     int i=0;
-    m_includeType = DEFAULT;
+    m_includeType = Default;
     m_isSystem = false;
     
     if(func.arguments[i].value=="AFTER") {
-        if(m_includeType!=DEFAULT)
+        if(m_includeType!=Default)
             return false;
-        m_includeType = AFTER;
+        m_includeType = After;
         i++;
     }
     
     if(func.arguments[i].value=="BEFORE") {
-        if(m_includeType!=DEFAULT)
+        if(m_includeType!=Default)
             return false;
-        m_includeType = BEFORE;
+        m_includeType = Before;
         i++;
     }
 
@@ -2004,9 +1868,6 @@ IncludeExternalMsProjectAst::~IncludeExternalMsProjectAst()
 {
 }
 
-void IncludeExternalMsProjectAst::writeBack( QString& ) const
-{
-}
 
 bool IncludeExternalMsProjectAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2022,9 +1883,6 @@ IncludeRegularExpressionAst::~IncludeRegularExpressionAst()
 {
 }
 
-void IncludeRegularExpressionAst::writeBack( QString& ) const
-{
-}
 
 bool IncludeRegularExpressionAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2044,9 +1902,6 @@ InstallAst::~InstallAst()
 {
 }
 
-void InstallAst::writeBack( QString& ) const
-{
-}
 
 bool InstallAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2062,9 +1917,6 @@ InstallFilesAst::~InstallFilesAst()
 {
 }
 
-void InstallFilesAst::writeBack( QString& ) const
-{
-}
 
 bool InstallFilesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2096,9 +1948,6 @@ InstallProgramsAst::~InstallProgramsAst()
 {
 }
 
-void InstallProgramsAst::writeBack( QString& ) const
-{
-}
 
 bool InstallProgramsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2131,9 +1980,6 @@ InstallTargetsAst::~InstallTargetsAst()
 {
 }
 
-void InstallTargetsAst::writeBack( QString& ) const
-{
-}
 
 bool InstallTargetsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2164,9 +2010,6 @@ LinkDirectoriesAst::~LinkDirectoriesAst()
 {
 }
 
-void LinkDirectoriesAst::writeBack( QString& ) const
-{
-}
 
 bool LinkDirectoriesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2186,9 +2029,6 @@ LinkLibrariesAst::~LinkLibrariesAst()
 {
 }
 
-void LinkLibrariesAst::writeBack( QString& ) const
-{
-}
 
 bool LinkLibrariesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2223,9 +2063,6 @@ ListAst::~ListAst()
 {
 }
 
-void ListAst::writeBack( QString& ) const
-{
-}
 
 bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2236,36 +2073,36 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 
     QString argName = func.arguments.first().value;
     if(argName=="LENGTH")
-        m_type = LENGTH;
+        m_type = Length;
     else if(argName=="GET")
-        m_type=GET;
+        m_type=Get;
     else if(argName=="APPEND")
-        m_type = APPEND;
+        m_type = Append;
     else if(argName=="FIND")
-        m_type = FIND;
+        m_type = Find;
     else if(argName=="INSERT")
-        m_type = INSERT;
+        m_type = Insert;
     else if(argName=="REMOVE_ITEM")
-        m_type = REMOVE_ITEM;
+        m_type = RemoveItem;
     else if(argName=="REMOVE_AT")
-        m_type = REMOVE_AT;
+        m_type = RemoveAt;
     else if(argName=="SORT")
-        m_type = SORT;
+        m_type = Sort;
     else if(argName=="REVERSE")
-        m_type = REVERSE;
+        m_type = Reverse;
     else
         return false;
 
     m_list = func.arguments[1].value;
     switch(m_type)
     {
-        case LENGTH:
+        case Length:
             if(func.arguments.count()!=3)
                 return false;
             m_output = func.arguments[2].value;
             addOutputArgument(func.arguments[2]);
             break;
-        case GET: {
+        case Get: {
             if(func.arguments.count()<3)
                 return false;
             
@@ -2284,7 +2121,7 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 i++;
             }
         } break;
-        case APPEND: {
+        case Append: {
             if(func.arguments.count()<3)
                 return false;
             
@@ -2297,7 +2134,7 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 i++;
             }
         } break;
-        case FIND: {
+        case Find: {
             if(func.arguments.count()!=4)
                 return false;
             m_elements.append(func.arguments[2].value);
@@ -2305,7 +2142,7 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 
             addOutputArgument(func.arguments[3]);
         } break;
-        case INSERT: {
+        case Insert: {
             bool correct;
             if(func.arguments.count()<4)
                 return false;
@@ -2321,7 +2158,7 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 i++;
             }
         } break;
-        case REMOVE_ITEM: {
+        case RemoveItem: {
             if(func.arguments.count()<3)
                 return false;
             int i=0;
@@ -2333,7 +2170,7 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 i++;
             }
         } break;
-        case REMOVE_AT: {
+        case RemoveAt: {
             if(func.arguments.count()<3)
                 return false;
             addOutputArgument(func.arguments[1]);
@@ -2350,8 +2187,8 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 i++;
             }
         } break;
-        case SORT:
-        case REVERSE:
+        case Sort:
+        case Reverse:
             addOutputArgument(func.arguments[1]);
             if(func.arguments.count()>2)
                 return false;
@@ -2368,9 +2205,6 @@ LoadCacheAst::~LoadCacheAst()
 {
 }
 
-void LoadCacheAst::writeBack( QString& ) const
-{
-}
 
 bool LoadCacheAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2426,9 +2260,6 @@ LoadCommandAst::~LoadCommandAst()
 {
 }
 
-void LoadCommandAst::writeBack( QString& ) const
-{
-}
 
 bool LoadCommandAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2450,9 +2281,6 @@ MacroAst::~MacroAst()
 {
 }
 
-void MacroAst::writeBack( QString& ) const
-{
-}
 
 bool MacroAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2475,9 +2303,6 @@ FunctionAst::~FunctionAst()
 {
 }
 
-void FunctionAst::writeBack( QString& ) const
-{
-}
 
 bool FunctionAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2500,9 +2325,6 @@ MakeDirectoryAst::~MakeDirectoryAst()
 {
 }
 
-void MakeDirectoryAst::writeBack( QString& ) const
-{
-}
 
 bool MakeDirectoryAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2520,9 +2342,6 @@ MarkAsAdvancedAst::~MarkAsAdvancedAst()
 {
 }
 
-void MarkAsAdvancedAst::writeBack( QString& ) const
-{
-}
 
 
 bool MarkAsAdvancedAst::parseFunctionInfo( const CMakeFunctionDesc& func )
@@ -2559,9 +2378,6 @@ MathAst::~MathAst()
 {
 }
 
-void MathAst::writeBack( QString& ) const
-{
-}
 
 bool MathAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2582,9 +2398,6 @@ MessageAst::~MessageAst()
 {
 }
 
-void MessageAst::writeBack( QString& ) const
-{
-}
 
 bool MessageAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2593,11 +2406,11 @@ bool MessageAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     if(func.arguments.count()>1) {
         QString type=func.arguments.first().value;
         if(type=="SEND_ERROR")
-            m_type=SEND_ERROR;
+            m_type=SendError;
         else if(type=="STATUS")
-            m_type=STATUS;
+            m_type=Status;
         else if(type=="FATAL_ERROR")
-            m_type=FATAL_ERROR;
+            m_type=FatalError;
     }
     
     m_message.append(func.arguments.last().value); //Maybe should do a foreach
@@ -2612,9 +2425,6 @@ OptionAst::~OptionAst()
 {
 }
 
-void OptionAst::writeBack( QString& ) const
-{
-}
 
 bool OptionAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2636,9 +2446,6 @@ OutputRequiredFilesAst::~OutputRequiredFilesAst()
 {
 }
 
-void OutputRequiredFilesAst::writeBack( QString& ) const
-{
-}
 
 bool OutputRequiredFilesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2657,9 +2464,6 @@ ProjectAst::~ProjectAst()
 {
 }
 
-void ProjectAst::writeBack( QString& ) const
-{
-}
 
 bool ProjectAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2696,9 +2500,6 @@ QtWrapCppAst::~QtWrapCppAst()
 {
 }
 
-void QtWrapCppAst::writeBack( QString& ) const
-{
-}
 
 bool QtWrapCppAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2714,9 +2515,6 @@ QtWrapUiAst::~QtWrapUiAst()
 {
 }
 
-void QtWrapUiAst::writeBack( QString& ) const
-{
-}
 
 bool QtWrapUiAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2732,9 +2530,6 @@ RemoveAst::~RemoveAst()
 {
 }
 
-void RemoveAst::writeBack( QString& ) const
-{
-}
 
 bool RemoveAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2759,9 +2554,6 @@ RemoveDefinitionsAst::~RemoveDefinitionsAst()
 {
 }
 
-void RemoveDefinitionsAst::writeBack( QString& ) const
-{
-}
 
 bool RemoveDefinitionsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2784,9 +2576,6 @@ SeparateArgumentsAst::~SeparateArgumentsAst()
 {
 }
 
-void SeparateArgumentsAst::writeBack( QString& ) const
-{
-}
 
 bool SeparateArgumentsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2807,9 +2596,6 @@ SetAst::~SetAst()
 {
 }
 
-void SetAst::writeBack( QString& ) const
-{
-}
 
 bool SetAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2865,9 +2651,6 @@ SetDirectoryPropsAst::~SetDirectoryPropsAst()
 {
 }
 
-void SetDirectoryPropsAst::writeBack( QString& ) const
-{
-}
 
 bool SetDirectoryPropsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2911,9 +2694,6 @@ SetSourceFilesPropsAst::~SetSourceFilesPropsAst()
 {
 }
 
-void SetSourceFilesPropsAst::writeBack( QString& ) const
-{
-}
 
 bool SetSourceFilesPropsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -2957,9 +2737,6 @@ SetTargetPropsAst::~SetTargetPropsAst()
 {
 }
 
-void SetTargetPropsAst::writeBack( QString& ) const
-{
-}
 
 bool SetTargetPropsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3003,9 +2780,6 @@ SetTestsPropsAst::~SetTestsPropsAst()
 {
 }
 
-void SetTestsPropsAst::writeBack( QString& ) const
-{
-}
 
 bool SetTestsPropsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3049,9 +2823,6 @@ SiteNameAst::~SiteNameAst()
 {
 }
 
-void SiteNameAst::writeBack( QString& ) const
-{
-}
 
 bool SiteNameAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3070,9 +2841,6 @@ SourceGroupAst::~SourceGroupAst()
 {
 }
 
-void SourceGroupAst::writeBack( QString& ) const
-{
-}
 
 bool SourceGroupAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3112,9 +2880,6 @@ StringAst::~StringAst()
 {
 }
 
-void StringAst::writeBack( QString& ) const
-{
-}
 
 bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3125,14 +2890,14 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     {
         if(func.arguments.count()<5)
             return false;
-        m_type=REGEX;
+        m_type=Regex;
         QString regexType = func.arguments[1].value.toUpper();
 
         int outpos=3;
-        if(regexType=="MATCH") m_cmdType=MATCH;
-        else if(regexType=="MATCHALL") m_cmdType=MATCHALL;
+        if(regexType=="MATCH") m_cmdType=Match;
+        else if(regexType=="MATCHALL") m_cmdType=MatchAll;
         else if(regexType=="REPLACE") {
-            m_cmdType=REGEX_REPLACE; 
+            m_cmdType=RegexReplace; 
             m_replace=func.arguments[3].value;
             outpos=4;
         }
@@ -3151,7 +2916,7 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     }
     else if(stringType=="REPLACE")
     {
-        m_type=REPLACE;
+        m_type=Replace;
         m_regex = func.arguments[1].value;
         m_replace=func.arguments[2].value;
         m_outputVariable = func.arguments[3].value;
@@ -3168,12 +2933,12 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     {
         if(func.arguments.count()!=5)
             return false;
-        m_type=COMPARE;
+        m_type=Compare;
         QString argumentType=func.arguments[1].value.toUpper();
-        if(argumentType=="EQUAL") m_cmdType=EQUAL;
-        else if(argumentType=="NOTEQUAL") m_cmdType=NOTEQUAL;
-        else if(argumentType=="LESS") m_cmdType=LESS;
-        else if(argumentType=="GREATER") m_cmdType=GREATER;
+        if(argumentType=="EQUAL") m_cmdType=Equal;
+        else if(argumentType=="NOTEQUAL") m_cmdType=NotEqual;
+        else if(argumentType=="LESS") m_cmdType=Less;
+        else if(argumentType=="GREATER") m_cmdType=Greater;
         
         m_input.append(func.arguments[2].value);
         m_input.append(func.arguments[3].value);
@@ -3182,7 +2947,7 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     }
     else if(stringType=="ASCII")
     {
-        m_type=ASCII;
+        m_type=Ascii;
         QList<CMakeFunctionArgument>::const_iterator it=func.arguments.begin()+1;
         QList<CMakeFunctionArgument>::const_iterator itEnd=func.arguments.end();
         for(; it!=itEnd; ++it)
@@ -3195,7 +2960,7 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     }
     else if(stringType=="CONFIGURE")
     {
-        m_type=CONFIGURE;
+        m_type=Configure;
         if(func.arguments.isEmpty())
             return false;
         m_input += func.arguments[1].value;
@@ -3209,20 +2974,20 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     }
     else if(stringType=="TOUPPER")
     {
-        m_type=TOUPPER;
+        m_type=ToUpper;
         m_input.append(func.arguments[1].value);
         m_outputVariable = func.arguments[2].value;
     }
     else if(stringType=="TOLOWER")
     {
-        m_type=TOLOWER;
+        m_type=ToLower;
         m_input.append(func.arguments[1].value);
         m_outputVariable = func.arguments[2].value;
         addOutputArgument(func.arguments[2]);
     }
     else if(stringType=="LENGTH")
     {
-        m_type=LENGTH;
+        m_type=Length;
         m_input.append(func.arguments[1].value);
         m_outputVariable = func.arguments[2].value;
         
@@ -3233,7 +2998,7 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
         if(func.arguments.count()<5)
             return false;
         bool correctBegin, correctLength;
-        m_type=SUBSTRING;
+        m_type=Substring;
         m_input.append(func.arguments[1].value);
         m_begin = func.arguments[2].value.toInt(&correctBegin);
         m_length = func.arguments[3].value.toInt(&correctLength);
@@ -3244,7 +3009,7 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     }
     else if(stringType=="STRIP")
     {
-        m_type=STRIP;
+        m_type=Strip;
         if(func.arguments.count()!=3)
             return false;
         m_string = func.arguments[1].value;
@@ -3255,8 +3020,8 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     {
         if(func.arguments.count()>6 || func.arguments.count()<2)
             return false;
-        m_type=RANDOM;
-        enum State { ALPHABET, LENGTH, None };
+        m_type=Random;
+        enum State { Alphabet, Length, None };
         State s = None;
         m_length=5;
         m_string="abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
@@ -3268,11 +3033,11 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
             
             bool correct=true;
             switch(s) {
-                case ALPHABET:
+                case Alphabet:
                     m_regex=arg.value;
                     s=None;
                     continue;
-                case LENGTH:
+                case Length:
                     m_length = arg.value.toInt(&correct);
                     if(!correct) return false;
                     s=None;
@@ -3282,9 +3047,9 @@ bool StringAst::parseFunctionInfo( const CMakeFunctionDesc& func )
             }
             
             if(arg.value=="LENGTH")
-                s = LENGTH;
+                s = Length;
             else if(arg.value=="ALPHABET")
-                s = ALPHABET;
+                s = Alphabet;
             else
             {
                 s=None;
@@ -3310,9 +3075,6 @@ SubdirDependsAst::~SubdirDependsAst()
 {
 }
 
-void SubdirDependsAst::writeBack( QString& ) const
-{
-}
 
 bool SubdirDependsAst::parseFunctionInfo( const CMakeFunctionDesc& func)
 {
@@ -3330,9 +3092,6 @@ SubdirsAst::~SubdirsAst()
 {
 }
 
-void SubdirsAst::writeBack( QString& ) const
-{
-}
 
 bool SubdirsAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3367,9 +3126,6 @@ TargetLinkLibrariesAst::~TargetLinkLibrariesAst()
 {
 }
 
-void TargetLinkLibrariesAst::writeBack( QString& ) const
-{
-}
 
 bool TargetLinkLibrariesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3420,9 +3176,6 @@ TryCompileAst::~TryCompileAst()
 {
 }
 
-void TryCompileAst::writeBack( QString& ) const
-{
-}
 
 bool TryCompileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3484,9 +3237,6 @@ TryRunAst::~TryRunAst()
 {
 }
 
-void TryRunAst::writeBack( QString& ) const
-{
-}
 
 bool TryRunAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3548,9 +3298,6 @@ UseMangledMesaAst::~UseMangledMesaAst()
 {
 }
 
-void UseMangledMesaAst::writeBack( QString& ) const
-{
-}
 
 bool UseMangledMesaAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3569,9 +3316,6 @@ UtilitySourceAst::~UtilitySourceAst()
 {
 }
 
-void UtilitySourceAst::writeBack( QString& ) const
-{
-}
 
 bool UtilitySourceAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3599,9 +3343,6 @@ VariableRequiresAst::~VariableRequiresAst()
 {
 }
 
-void VariableRequiresAst::writeBack( QString& ) const
-{
-}
 
 bool VariableRequiresAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3631,9 +3372,6 @@ VtkMakeInstantiatorAst::~VtkMakeInstantiatorAst()
 {
 }
 
-void VtkMakeInstantiatorAst::writeBack( QString& ) const
-{
-}
 
 bool VtkMakeInstantiatorAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3649,9 +3387,6 @@ VtkWrapJavaAst::~VtkWrapJavaAst()
 {
 }
 
-void VtkWrapJavaAst::writeBack( QString& ) const
-{
-}
 
 bool VtkWrapJavaAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3667,9 +3402,6 @@ VtkWrapPythonAst::~VtkWrapPythonAst()
 {
 }
 
-void VtkWrapPythonAst::writeBack( QString& ) const
-{
-}
 
 bool VtkWrapPythonAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3685,9 +3417,6 @@ VtkWrapTclAst::~VtkWrapTclAst()
 {
 }
 
-void VtkWrapTclAst::writeBack( QString& ) const
-{
-}
 
 bool VtkWrapTclAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3703,9 +3432,6 @@ WhileAst::~WhileAst()
 {
 }
 
-void WhileAst::writeBack( QString& ) const
-{
-}
 
 bool WhileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3727,9 +3453,6 @@ WriteFileAst::~WriteFileAst()
 {
 }
 
-void WriteFileAst::writeBack( QString& ) const
-{
-}
 
 bool WriteFileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3758,9 +3481,6 @@ CustomInvokationAst::~CustomInvokationAst()
 {
 }
 
-void CustomInvokationAst::writeBack( QString& ) const
-{
-}
 
 bool CustomInvokationAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3777,9 +3497,6 @@ BreakAst::~BreakAst()
 {
 }
 
-void BreakAst::writeBack( QString& ) const
-{
-}
 
 bool BreakAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3794,9 +3511,6 @@ CMakePolicyAst::~CMakePolicyAst()
 {
 }
 
-void CMakePolicyAst::writeBack( QString& ) const
-{
-}
 
 bool CMakePolicyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3815,7 +3529,7 @@ bool CMakePolicyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     }
     else if(first=="SET" && func.arguments.count()==3)
     {
-        QRegExp rx("CMP([1-9]*)");
+        static QRegExp rx("CMP([1-9]*)");
         rx.indexIn(func.arguments[1].value);
 
         QStringList cmpValue=rx.capturedTexts();
@@ -3834,10 +3548,10 @@ bool CMakePolicyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
             return false;
         return true;
     } else if(first=="PUSH") {
-        m_action=PUSH;
+        m_action=Push;
         return func.arguments.count()==1;
     } else if(first=="POP") {
-        m_action=POP;
+        m_action=Pop;
         return func.arguments.count()==1;
     }
     return false;
@@ -3851,9 +3565,6 @@ ExportAst::~ExportAst()
 {
 }
 
-void ExportAst::writeBack( QString& ) const
-{
-}
 
 bool ExportAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3909,9 +3620,6 @@ ReturnAst::~ReturnAst()
 {
 }
 
-void ReturnAst::writeBack( QString& ) const
-{
-}
 
 bool ReturnAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3926,9 +3634,6 @@ SetPropertyAst::~SetPropertyAst()
 {
 }
 
-void SetPropertyAst::writeBack( QString& ) const
-{
-}
 
 bool SetPropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
@@ -3936,11 +3641,11 @@ bool SetPropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
         return false;
     
     QString propName=func.arguments.first().value;
-    if(propName=="GLOBAL") m_type=GLOBAL;
-    else if(propName=="DIRECTORY") m_type=DIRECTORY;
-    else if(propName=="TARGET") m_type=TARGET;
-    else if(propName=="SOURCE") m_type=SOURCE;
-    else if(propName=="TEST") m_type=TEST;
+    if(propName=="GLOBAL") m_type=GlobalProperty;
+    else if(propName=="DIRECTORY") m_type=DirectoryProperty;
+    else if(propName=="TARGET") m_type=TargetProperty;
+    else if(propName=="SOURCE") m_type=SourceProperty;
+    else if(propName=="TEST") m_type=TestProperty;
     else
         return false;
     
@@ -3976,9 +3681,6 @@ GetPropertyAst::GetPropertyAst()
 GetPropertyAst::~GetPropertyAst()
 {}
 
-void GetPropertyAst::writeBack( QString& ) const
-{}
-
 bool GetPropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if(func.name.toLower()!="get_property" || func.arguments.count() < 4 || func.arguments.count() > 6)
@@ -3990,12 +3692,12 @@ bool GetPropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     
     PropertyType t;
     QString propName=it->value;
-    if(propName=="GLOBAL") t=GLOBAL;
-    else if(propName=="DIRECTORY") t=DIRECTORY;
-    else if(propName=="TARGET") t=TARGET;
-    else if(propName=="SOURCE") t=SOURCE;
-    else if(propName=="TEST") t=TEST;
-    else if(propName=="VARIABLE") t=VARIABLE;
+    if(propName=="GLOBAL") t=GlobalProperty;
+    else if(propName=="DIRECTORY") t=DirectoryProperty;
+    else if(propName=="TARGET") t=TargetProperty;
+    else if(propName=="SOURCE") t=SourceProperty;
+    else if(propName=="TEST") t=TestProperty;
+    else if(propName=="VARIABLE") t=VariableProperty;
     else
         return false;
     ++it;
@@ -4011,11 +3713,11 @@ bool GetPropertyAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     m_behaviour=None;
     if(it!=itEnd) {
         QString ee=it->value;
-        if(ee=="SET") m_behaviour=SET;
-        else if(ee=="DEFINED") m_behaviour=DEFINED;
-        else if(ee=="BRIEF_DOCS") m_behaviour=BRIEF_DOCS;
-        else if(ee=="FULL_DOCS") m_behaviour=FULL_DOCS;
+        if(ee=="SET") m_behaviour=Set;
+        else if(ee=="DEFINED") m_behaviour=Defined;
+        else if(ee=="BRIEF_DOCS") m_behaviour=BriefDocs;
+        else if(ee=="FULL_DOCS") m_behaviour=FullDocs;
     }
     
     return !m_name.isEmpty();
-}
\ No newline at end of file
+}
